@@ -1,6 +1,6 @@
 from .fuzzy_sets import FuzzySet, MF_object, Triangular_MF, SingletonsSet
 from .rule_parsing import recursive_parse, preparse, postparse
-from numpy import array, linspace, logspace, log10, finfo, float64
+from numpy import array, linspace, geomspace, log10, finfo, float64
 from scipy.interpolate import interp1d
 from copy import deepcopy
 from collections import defaultdict, OrderedDict
@@ -8,10 +8,13 @@ import re
 import string
 try:
 	from matplotlib.pyplot import plot, show, title, subplots, legend
-	import seaborn as sns
 	matplotlib = True
 except ImportError:
 	matplotlib = False
+try:
+	import seaborn as sns
+except:
+	pass
 
 # constant values
 linestyles= ["-", "--", ":", "-."]
@@ -98,12 +101,13 @@ class LinguisticVariable(object):
 		if xscale == "linear":
 			x = linspace(mi, ma, 10000)
 		elif xscale == "log":
-			if mi < 0:
-				raise Exception("ERROR: cannot plot in log scale with negative universe of discourse")
+			if mi < 0 and ma > 0:
+				x = geomspace(mi, -finfo(float64).eps, 5000) + geomspace(finfo(float64).eps, ma, 5000)
+				# raise Exception("ERROR: cannot plot in log scale with negative universe of discourse")
 			elif mi == 0:
-				x = logspace(log10(finfo(float64).eps), log10(ma), 10000)
+				x = geomspace(finfo(float64).eps, ma, 10000)
 			else:
-				x = logspace(log10(mi), log10(ma), 10000)
+				x = geomspace(mi, ma, 10000)
 		else:
 			raise Exception("ERROR: scale "+xscale+" not supported.")
 
@@ -116,7 +120,6 @@ class LinguisticVariable(object):
 
 		for nn, fs in enumerate(self._FSlist):
 			if isinstance(fs, SingletonsSet):
-				print(fs._funpointer._pairs)
 				xs = [pair[0] for pair in fs._funpointer._pairs]
 				ys = [pair[1] for pair in fs._funpointer._pairs]
 				ax.vlines(x=xs, ymin=0.0, ymax=ys, linestyles=linestyles[nn%4], color=next(ax._get_lines.prop_cycler)['color'], label=fs._term)
@@ -139,9 +142,9 @@ class LinguisticVariable(object):
 			ax.axvline(x=TGT, ymin=0.0, ymax=1.0, color="red", linestyle="--", linewidth=2.0)
 		ax.set_xlabel(self._concept)
 		ax.set_ylabel("Membership degree")
-		ax.set_ylim(bottom=-0.05)
+		ax.set_ylim(bottom=-0.05, top=1.05)
 		if xscale == "log":
-			ax.set_xscale("symlog")
+			ax.set_xscale("symlog", linthresh=10e-2)
 			ax.set_xlim(x[0], x[-1])
 		if highlight is None: ax.legend(loc="best")
 		return ax
@@ -622,7 +625,7 @@ class FuzzySystem(object):
 		Returns:
 			a dictionary, containing as keys the variables' names and as values their numerical inferred values.
 		"""
-		if self._sanitize and terms is not None: 
+		if self._sanitize_input and terms is not None: 
 			terms = [self._sanitize(term) for term in terms]
 		
 		# default: inference on ALL rules/terms
@@ -665,7 +668,7 @@ class FuzzySystem(object):
 		Returns:
 			a dictionary, containing as keys the variables' names and as values their numerical inferred values.
 		"""
-		if self._sanitize and terms is not None: 
+		if self._sanitize_input and terms is not None: 
 			terms = [self._sanitize(term) for term in terms]
 		
 		# default: inference on ALL rules/terms
